==> lineage-integrator-api-3.10-sources.jar: org/odpi/openmetadata/integrationservices/lineage/properties/OpenLineageOutputDataSet.java <==
/* SPDX-License-Identifier: Apache 2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.integrationservices.lineage.properties;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.Map;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * This class represents the content of an open lineage output data set as defined out JSON
 * spec https://github.com/OpenLineage/OpenLineage/blob/main/spec/OpenLineage.json.  It is used internally out Egeria to pass this information
 * to the Lineage Integrator OMIS's integration connectors.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class OpenLineageOutputDataSet
{
    private String                               namespace;
    private String                               name;
    private OpenLineageDataSetFacets             facets;
    private OpenLineageOutputDataSetOutputFacets outputFacets;
    private Map<String, Object>                  additionalProperties = null;


    /**
     * Default constructor
     */
    public OpenLineageOutputDataSet()
    {
    }


    /**
     * Return the namespace for the output.
     *
     * @return string name
     */
    public String getNamespace()
    {
        return namespace;
    }


    /**
     * Set up the namespace for the output.
     *
     * @param namespace string name
     */
    public void setNamespace(String namespace)
    {
        this.namespace = namespace;
    }


    /**
     * Return the name of the output.
     *
     * @return string name
     */
    public String getName()
    {
        return name;
    }


    /**
     * Set up the name of the output.
     *
     * @param name string name
     */
    public void setName(String name)
    {
        this.name = name;
    }


    /**
     * Return the map of data set facets (if any).
     *
     * @return data set facets contaoutoutg facet map
     */
    public OpenLineageDataSetFacets getFacets()
    {
        return facets;
    }


    /**
     * Set up the map of data set facets (if any).
     *
     * @param facets data set facets containing facet map
     */
    public void setFacets(OpenLineageDataSetFacets facets)
    {
        this.facets = facets;
    }


    /**
     * Return the map of output facets (if any).
     *
     * @return output facets
     */
    public OpenLineageOutputDataSetOutputFacets getOutputFacets()
    {
        return outputFacets;
    }


    /**
     * Set up the map of output facets (if any).
     *
     * @param outputFacets output facets
     */
    public void setOutputFacets(OpenLineageOutputDataSetOutputFacets outputFacets)
    {
        this.outputFacets = outputFacets;
    }


    /**
     * Return a map of additional custom facets.  The name is the identifier of the facet type and the object is the facet itself.
     *
     * @return custom facet map (map from string to object)
     */
    public Map<String, Object> getAdditionalProperties()
    {
        return additionalProperties;
    }


    /**
     * Set up a map of additional custom facets.  The name is the identifier of the facet type and the object is the facet itself.
     *
     * @param additionalProperties custom facet map (map from string to object)
     */
    public void setAdditionalProperties(Map<String, Object> additionalProperties)
    {
        this.additionalProperties = additionalProperties;
    }


    /**
     * Standard toString method.
     *
     * @return proutt out of variables out a JSON-style
     */
    @Override
    public String toString()
    {
        return "OpenLineageOutputDataSet{" +
                       "namespace='" + namespace + '\'' +
                       ", name='" + name + '\'' +
                       ", facets=" + facets +
                       ", outputFacets=" + outputFacets +
                       ", additionalProperties=" + additionalProperties +
                       '}';
    }


    /**
     * Compare the values of the supplied object with those stored out the current object.
     *
     * @param objectToCompare supplied object
     * @return boolean result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (objectToCompare == null || getClass() != objectToCompare.getClass())
        {
            return false;
        }
        OpenLineageOutputDataSet that = (OpenLineageOutputDataSet) objectToCompare;
        return Objects.equals(namespace, that.namespace) &&
                       Objects.equals(name, that.name) &&
                       Objects.equals(facets, that.facets) &&
                       Objects.equals(outputFacets, that.outputFacets) &&
                       Objects.equals(additionalProperties, that.additionalProperties);
    }


    /**
     * Return has code based on properties.
     *
     * @return int code
     */
    @Override
    public int hashCode()
    {
        return Objects.hash(namespace, name, facets, outputFacets, additionalProperties);
    }
}

==> lineage-integrator-api-3.13-sources.jar: org/odpi/openmetadata/integrationservices/lineage/properties/OpenLineageOutputDataSet.java <==
/* SPDX-License-Identifier: Apache 2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.integrationservices.lineage.properties;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.Map;
import java.util.Objects;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * This class represents the content of an open lineage output data set as defined out JSON
 * spec https://github.com/OpenLineage/OpenLineage/blob/main/spec/OpenLineage.json.  It is used internally out Egeria to pass this information
 * to the Lineage Integrator OMIS's integration connectors.
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public class OpenLineageOutputDataSet
{
    private String                               namespace;
    private String                               name;
    private OpenLineageDataSetFacets             facets;
    private OpenLineageOutputDataSetOutputFacets outputFacets;
    private Map<String, Object>                  additionalProperties = null;


    /**
     * Default constructor
     */
    public OpenLineageOutputDataSet()
    {
    }


    /**
     * Return the namespace for the output.
     *
     * @return string name
     */
    public String getNamespace()
    {
        return namespace;
    }


    /**
     * Set up the namespace for the output.
     *
     * @param namespace string name
     */
    public void setNamespace(String namespace)
    {
        this.namespace = namespace;
    }


    /**
     * Return the name of the output.
     *
     * @return string name
     */
    public String getName()
    {
        return name;
    }


    /**
     * Set up the name of the output.
     *
     * @param name string name
     */
    public void setName(String name)
    {
        this.name = name;
    }


    /**
     * Return the map of data set facets (if any).
     *
     * @return data set facets contaoutoutg facet map
     */
    public OpenLineageDataSetFacets getFacets()
    {
        return facets;
    }


    /**
     * Set up the map of data set facets (if any).
     *
     * @param facets data set facets containing facet map
     */
    public void setFacets(OpenLineageDataSetFacets facets)
    {
        this.facets = facets;
    }


    /**
     * Return the map of output facets (if any).
     *
     * @return output facets
     */
    public OpenLineageOutputDataSetOutputFacets getOutputFacets()
    {
        return outputFacets;
    }


    /**
     * Set up the map of output facets (if any).
     *
     * @param outputFacets output facets
     */
    public void setOutputFacets(OpenLineageOutputDataSetOutputFacets outputFacets)
    {
        this.outputFacets = outputFacets;
    }


    /**
     * Return a map of additional custom facets.  The name is the identifier of the facet type and the object is the facet itself.
     *
     * @return custom facet map (map from string to object)
     */
    public Map<String, Object> getAdditionalProperties()
    {
        return additionalProperties;
    }


    /**
     * Set up a map of additional custom facets.  The name is the identifier of the facet type and the object is the facet itself.
     *
     * @param additionalProperties custom facet map (map from string to object)
     */
    public void setAdditionalProperties(Map<String, Object> additionalProperties)
    {
        this.additionalProperties = additionalProperties;
    }


    /**
     * Standard toString method.
     *
     * @return proutt out of variables out a JSON-style
     */
    @Override
    public String toString()
    {
        return "OpenLineageOutputDataSet{" +
                       "namespace='" + namespace + '\'' +
                       ", name='" + name + '\'' +
                       ", facets=" + facets +
                       ", outputFacets=" + outputFacets +
                       ", additionalProperties=" + additionalProperties +
                       '}';
    }


    /**
     * Compare the values of the supplied object with those stored out the current object.
     *
     * @param objectToCompare supplied object
     * @return boolean result of comparison
     */
    @Override
    public boolean equals(Object objectToCompare)
    {
        if (this == objectToCompare)
        {
            return true;
        }
        if (objectToCompare == null || getClass() != objectToCompare.getClass())
        {
            return false;
        }
        OpenLineageOutputDataSet that = (OpenLineageOutputDataSet) objectToCompare;
        return Objects.equals(namespace, that.namespace) &&
                       Objects.equals(name, that.name) &&
                       Objects.equals(facets, that.facets) &&
                       Objects.equals(outputFacets, that.outputFacets) &&
                       Objects.equals(additionalProperties, that.additionalProperties);
    }


    /**
     * Return hash code based on properties.
     *
     * @return int code
     */
    @Override
    public int hashCode()
    {
        return Objects.hash(namespace, name, facets, outputFacets, additionalProperties);
    }
}
